Create an actual raster::raster object by breaking the lazy contract and demanding pixel values at a given resolution.
as_raster(x, dim = NULL, resample = "NearestNeighbour", native = FALSE)dimensions, pixel size in rows and columns
resampling method, see vapour::vapour_read_raster
return raster at native resolution, default is FALSE
a regular raster 'BasicRaster' in-memory object
Control the dimensions and method for resampling with the 'dim' and 'resample' arguments.
When native = TRUE the dim argument is ignored, and no resampling is performed.