For crop() this set an active window of data using the same crop()
function as the raster package. This is the data window that will be pulled
by conversion to an actual raster by as_raster().
# NOT RUN {sstfile <- system.file("extdata/sst.tif", package = "vapour")
lr <- lazyraster(sstfile)
## crop and stay as lazyrastercrop(lazyraster(sstfile), raster::extent(142, 143, -50, -45))
# }